library(ggplot2)
library(lubridate)

#visualize user per month

users <- read.csv("./data/users.csv")

#adding month the users
users$month <- month(ymd(users$created_at))

#create the x axis
m <- c("2022-01-01", "2022-01-02","2022-01-03","2022-01-04","2022-01-05","2022-01-06","2022-01-07","2022-01-08","2022-01-09")
z <- as.Date(m,format = "%Y-%d-%m")


monthly_users <- data.frame(
  month = z,
  count = c(nrow(users[users$month == 1,]), 
    nrow(users[users$month == 2,]), 
    nrow(users[users$month == 3,]),
    nrow(users[users$month == 4,]),
    nrow(users[users$month == 5,]),
    nrow(users[users$month == 6,]),
    nrow(users[users$month == 7,]),
    nrow(users[users$month == 8,]),
    nrow(users[users$month == 9,]))
)

##users per month

fig <- plot_ly(
  data = monthly_users,
  x = ~month,
  y = ~count,
  name = "Users per month",
  type = "linear"
)
fig

users_events =  read.csv("./data/user_events.csv")

#adding month the dataframe
users_events$month <- month(ymd(users$created_at))

#filtering out users without events
users_w_events <- users_events[users_events$event_number > 0,]

monthly_users_evt <- data.frame(
  month = z,
  count = c(nrow(users_w_events[users_w_events$month == 1,]), 
            nrow(users_w_events[users_w_events$month == 2,]), 
            nrow(users_w_events[users_w_events$month == 3,]),
            nrow(users_w_events[users_w_events$month == 4,]),
            nrow(users_w_events[users_w_events$month == 5,]),
            nrow(users_w_events[users_w_events$month == 6,]),
            nrow(users_w_events[users_w_events$month == 7,]),
            nrow(users_w_events[users_w_events$month == 8,]),
            nrow(users_w_events[users_w_events$month == 9,]))
)

##users per month

viz <- plot_ly(
  data = monthly_users_evt,
  x = ~month,
  y = ~count,
  name = "Users per month",
  type = "bar"
)
viz

mean(monthly_users_evt$count)

## new users vs active new users

users_comparation <- data.frame(month = monthly_users_evt$month, 
                      active_users = monthly_users_evt$count, 
                      new_users = monthly_users$count )

viz <- plot_ly(
  data = users_comparation,
  x = ~month,
  y = ~active_users,
  name = "Actrive users",
  type = "scatter",
  mode = "lines"
)
viz <- viz %>% add_trace(y = ~new_users, name = 'New users',mode = 'lines') 

viz

## Project Metrics

projects <- read.csv("./data/projects_commits.csv")
projects$month <- month(ymd(as.Date(projects$created_at)))

monthly_projects <- data.frame(
  month = z,
  count = c(nrow(projects[projects$month == 1,]), 
            nrow(projects[projects$month == 2,]), 
            nrow(projects[projects$month == 3,]),
            nrow(projects[projects$month == 4,]),
            nrow(projects[projects$month == 5,]),
            nrow(projects[projects$month == 6,]),
            nrow(projects[projects$month == 7,]),
            nrow(projects[projects$month == 8,]),
            nrow(projects[projects$month == 9,]))
)

viz <- plot_ly(
  data = monthly_projects,
  x = ~month,
  y = ~count,
  name = "New Projects",
  type = "bar"
)
viz

#projects with commits
projects_commit <- projects[projects$commits_count > 1,]

monthly_projects_cmt <- data.frame(
  month = z,
  count = c(nrow(projects_commit[projects_commit$month == 1,]), 
            nrow(projects_commit[projects_commit$month == 2,]), 
            nrow(projects_commit[projects_commit$month == 3,]),
            nrow(projects_commit[projects_commit$month == 4,]),
            nrow(projects_commit[projects_commit$month == 5,]),
            nrow(projects_commit[projects_commit$month == 6,]),
            nrow(projects_commit[projects_commit$month == 7,]),
            nrow(projects_commit[projects_commit$month == 8,]),
            nrow(projects_commit[projects_commit$month == 9,]))
)

viz <- plot_ly(
  data = monthly_projects_cmt,
  x = ~month,
  y = ~count,
  name = "New Projects",
  type = "bar"
)
viz


## new projects vs active projects

projects_comparation <- data.frame(month = monthly_projects$month, 
                                active_projects = monthly_projects_cmt$count, 
                                new_projects = monthly_projects$count )

viz <- plot_ly(
  data = projects_comparation,
  x = ~month,
  y = ~active_projects,
  name = "Actrive projects",
  type = "scatter",
  mode = "lines"
)
viz <- viz %>% add_trace(y = ~new_projects, name = 'New projects',mode = 'lines') 

viz

head(projects_commit[rev(order(projects_commit$commits_count, as.Date(projects_commit$last_active))),])

